==> antragsgruen-3.6.3.tar.bz2: antragsgruen-3.6.3/messages/de/motion.php <==
<?php

return [
    'Start a Motion'                     => 'Antrag stellen',
    'Edit Motion'                        => 'Antrag bearbeiten',
    'Confirm Motion'                     => 'Antrag bestätigen',
    'confirm_bread'                      => 'Bestätigen',
    'create_prerequisites'               => 'Voraussetzungen für einen Antrag',
    'amendment_create'                   => 'Änderungsantrag stellen',
    'amendment_create_admin'             => 'nur Admins',
    'amendments_merge'                   => 'Änderungsanträge einpflegen',
    'amendments_merge_noamend'           => 'Änderungen einpflegen',
    'none_yet'                           => 'Es gibt noch keine Anträge',
    'motion_edit'                        => '%TYPE% bearbeiten',
    'motion_withdraw'                    => '%TYPE% zurückziehen',
    'motion_admin_edit'                  => 'Admin: bearbeiten',
    'back_start'                         => 'Zurück zur Übersicht',
    'pdf_version'                        => 'PDF-Version',
    'Type'                               => 'Typ',
    'Motion'                             => 'Antrag',
    'Initiator'                          => 'Antragsteller*in',
    'initiators_1'                       => 'Antragsteller*in',
    'initiators_x'                       => 'Antragsteller*innen',
    'initiators_head'                    => 'Antragsteller*innen',
    'Supporter'                          => 'Unterstützer*in',
    'supporters_heading'                 => 'Unterstützer*innen',
    'supporting_you'                     => 'Du!',
    'supporting_none'                    => 'keine',
    'supporting_logged_out_warning'      => 'Achtung: Du bist nicht eingeloggt. Unterstützungen, die ohne Login ausgesprochen werden, können nur für kurze Zeit zurückgenommen werden.',
    'supporting_no_orga_error'           => 'Achtung: dein Gremium konnte nicht ermittelt werden. Das ist zum Unterstützen aber notwendig. Bitte melde dich bei den Administrator*innen dieser Veranstaltung, um das Problem zu klären.',
    'likes_title'                        => 'Zustimmung',
    'like'                               => 'Zustimmung',
    'likes'                              => 'Zustimmung',
    'likes_you'                          => 'Du!',
    'dislike'                            => 'Ablehnung',
    'dislikes'                           => 'Ablehnung',
    'dislikes_you'                       => 'Du!',
    'like_withdraw'                      => 'Doch nicht',
    'submitted_create'                   => 'Antrag angelegt',
    'submitted_submit'                   => 'Antrag eingereicht',
    'submitted_publish'                  => 'Antrag veröffentlicht',
    'created_bread_create'               => 'Angelegt',
    'created_bread_submit'               => 'Eingereicht',
    'created_bread_publish'              => 'Veröffentlicht',
    'button_submit_create'               => 'Anlegen',
    'button_submit_submit'               => 'Einreichen',
    'button_submit_publish'              => 'Veröffentlichen',
    'button_correct'                     => 'Korrigieren',
    'Prefix'                             => 'Antragsnummer',
    'Title'                              => 'Titel',
    'replaces_motion'                    => 'Ersetzt',
    'consultation'                       => 'Veranstaltung',
    'comments'                           => 'Kommentare',
    'comment_screen_queue_1'             => '1 Kommentar wartet auf Freischaltung',
    'comment_screen_queue_x'             => '%NUM% Kommentare warten auf Freischaltung',
    'comment_login_hint'                 => 'Logge dich ein, um kommentieren zu können.',
    'status'                             => 'Status',
    'tag_none'                           => 'Keines',
    'as_pdf'                             => 'als PDF',
    'agenda_filter'                      => 'Tagesordnung',
    'agenda_item'                        => 'Tagesordnungspunkt',
    'resolution'                         => 'beschlossen',
    'resolution_on'                      => 'beschlossen am',
    'Resolution'                         => 'Beschlossen',
    'resoluted_on'                       => 'Entschieden am',
    'submitted_on'                       => 'Eingereicht',
    'tag_tags'                           => 'Themenbereich',
    'tag'                                => 'Themenbereich',
    'tags'                               => 'Themenbereiche',
    'tag_add'                            => 'Hinzufügen',
    'tag_select'                         => 'Thema aussuchen',
    'tag_new'                            => 'Neu',
    'tag_del'                            => 'del',
    'tags_head'                          => 'Themenbereich',
    'amends_none'                        => 'keine',
    'replaced_by_hint'                   => 'Achtung: dies ist eine alte Fassung; die aktuelle Fassung gibt es hier:',
    'confirmed_visible'                  => 'Du hast den Antrag veröffentlicht. Er ist jetzt sofort sichtbar.',
    'confirmed_screening'                => 'Du hast den Antrag eingereicht. ' .
        'Er wird nun auf formale Richtigkeit geprüft und dann freigeschaltet.',
    'confirmed_support_phase'            => 'Du hast den Antrag erfolgreich angelegt.<br>
Damit du den Antrag offiziell einreichen kannst, benötigt dieser mindestens %MIN% Unterstützer*innen.<br> 
<br>
Du kannst Interessierten folgenden Link schicken, damit sie deinen Antrag dort unterstützen können:',
    'confirmed_support_phase_ww'         => 'Über diesen Link kann dein Antrag gelesen und von Parteimitgliedern unterstützt werden, die damit mit Dir gemeinsam den Antrag stellen.<br> 
<br>
Bitte beachte, dass sich die Unterstützer*innen deines Antrags mit ihren Zugangsdaten für das Grüne Netz einloggen und darüber verifizieren müssen.',
    'copy_to_clipboard'                  => 'Adresse in die Zwischenablage kopieren',
    'copy_to_clipboard_done'             => 'Die Adresse wurde in die Zwischenablage kopiert.',
    'submitted_screening_email'          => "Hallo,\n\ndu hast soeben einen Antrag eingereicht.\n" .
        "Der Antrag wird nun auf formale Richtigkeit geprüft und dann freigeschaltet. " .
        "Du wirst dann gesondert darüber benachrichtigt.\n\n" .
        "Du kannst ihn hier einsehen: %LINK%\n\n" .
        "Mit freundlichen Grüßen,\n" .
        "  Das Antragsgrün-Team",
    'submitted_screening_email_subject'  => 'Antrag eingereicht',
    'submitted_supp_phase_email'         => "Hallo %NAME_GIVEN%\n\nDu hast den Antrag nun angelegt.\n" .
        "Um ihn offiziell einzureichen, benötigt er mindestens %MIN% Unterstützer*innen.\n\n" .
        "Du kannst Interessierten folgenden Link schicken, damit sie den Antrag dort unterstützen können:\n\n%LINK%\n",
    'submitted_supp_phase_email_subject' => 'Antrag erfolgreich angelegt',
    'submitted_adminnoti_title'          => 'Neuer Antrag',
    'submitted_adminnoti_body'           => "Es wurde ein neuer Antrag eingereicht.\nTitel: %TITLE%\nAntragsteller*in: %INITIATOR%\nLink: %LINK%",
    'screened_hint'                      => 'Geprüft',
    'supporting_permitted'               => 'Berechtigung',
    'download_pdf'                       => 'PDF-Version herunterladen',
    'motion_text'                        => 'Antragstext',
    'published_email_body'               => "Hallo,\n\ndein Antrag wurde soeben auf Antragsgrün veröffentlicht. " .
        "Du kannst ihn hier einsehen: %LINK%\n\n" .
        "Mit freundlichen Grüßen,\n" .
        "  Das Antragsgrün-Team",
    'published_email_title'              => 'Antrag veröffentlicht',
    'back_to_motion'                     => 'Zurück zum Antrag',
    'edit_done'                          => 'Antrag bearbeitet',
    'edit_done_msg'                      => 'Die Änderungen wurden übernommen.',
    'edit_bread'                         => 'Bearbeiten',
    'edit_mail_title'                    => 'Antrag überarbeitet',
    'edit_type'                          => '%TYPE% bearbeiten',
    'edit_mail_body'                     => 'Der Antrag "%TITLE%" wurde überarbeitet.' . "\n" . 'Link: %LINK%',
    'err_create_permission'              => 'Keine Berechtigung zum Anlegen von Anträgen.',
    'err_create'                         => 'Ein Fehler beim Anlegen ist aufgetreten',
    'err_edit_permission'                => 'Keine Berechtigung zum Bearbeiten dieses Antrags.',
    'err_withdraw_permission'            => 'Dieser Antrag kann nicht zurückgezogen werden.',
    'err_not_found'                      => 'Antrag nicht gefunden.',
    'err_not_visible_yet_title'          => 'Noch nicht sichtbar',
    'err_not_visible_yet'                => 'Dieser Antrag ist noch nicht sichtbar.',
    'withdraw_done'                      => 'Der Antrag wurde zurückgezogen.',
    'withdraw_bread'                     => 'Zurückziehen',
    'withdraw'                           => 'Zurückziehen',
    'withdraw_confirm'                   => 'Willst du diesen Antrag wirklich zurückziehen?',
    'withdraw_no'                        => 'Doch nicht',
    'withdraw_yes'                       => 'Zurückziehen',
    'withdrawn_adminnoti_title'          => 'Antrag zurückgezogen',
    'withdrawn_adminnoti_body'           => "Es wurde ein Antrag zurückgezogen.\nTitel: %TITLE%\nAntragsteller*in: %INITIATOR%\nLink: %LINK%",
    'max_len_hint'                       => 'Max. %LEN% Zeichen (Aktuell: %COUNT%)',
    'max_len_alert'                      => 'Der Text ist zu lang!',
    'create_explanation'                 => 'Wenn du einen <em>eigenständigen Antrag</em> stellen willst, bist du hier genau richtig.
        Wenn du einen <em>Änderungsantrag</em> stellen willst, öffne auf der <a href="%HOME%">Startseite</a>
        bitte zuerst den zu ändernden Antrag und wähle dann rechts oben "Änderungsantrag stellen".',
    'create_explanation_title'           => 'Antrag oder Änderungsantrag?',
    'support_collect_explanation_title'  => 'Einen Antrag gemeinschaftlich stellen',
    'support_collect_explanation'        => 'Ein Antrag, der nicht von Parteigremien gestellt wird, kann gemäß unserer Statuten auch gemeinschaftlich von %MIN+1% Mitgliedern gestellt werden. Um einen solchen Antrag zu stellen und offiziell bei der Antragskommission einzureichen, gehe bitte wie folgt vor:<br>
<ol>
<li><strong>Antrag anlegen:</strong> Bitte lege auf dieser Seite deinen Antrag an und hinterlege deine (Kontakt-)Daten. Kontrolliere auf der nächsten Seite, ob alles richtig ist, und bestätige, dass du den Antrag wie gezeigt anlegen möchtest.</li>
<li><strong>Unterstützung finden:</strong> Nach der Bestätigung erhältst du einen Link, den du Interessierten weiterleiten kannst. Über diesen Link kann dein Antrag gelesen und von Parteimitgliedern unterstützt werden, die damit mit Dir gemeinsam den Antrag stellen. Bitte beachte, dass sich auch die Unterstützer*innen deines Antrags mit ihren Zugangsdaten für das Grüne Netz einloggen und darüber verifizieren müssen.</li>
<li><strong>Antrag einreichen:</strong> Sobald sich die notwendigen %MIN% Unterstützer*innen gefunden haben, musst du den angelegten Antrag noch offiziell bei der Antragskommission einreichen. Dies veranlasst Du auch über Antragsgrün. Wir informieren dich selbstverständlich per E-Mail, sobald die notwendige Zahl der Unterstützer*innen erreicht ist.</li>
</ol>',
    'support_collect_status'             => 'Aktueller Stand',
    'support_collect_min'                => 'min.',
    'go_on'                              => 'Weiter',
    'like_done'                          => 'Du stimmst diesem Antrag nun zu.',
    'dislike_done'                       => 'Du lehnst diesen Antrag nun ab.',
    'support'                            => 'Unterstützen',
    'support_question'                   => 'Willst du den Antrag unterstützen?',
    'support_orga'                       => 'Organisation',
    'support_name'                       => 'Name',
    'support_done'                       => 'Du unterstützt diesen Antrag nun.',
    'neutral_done'                       => 'Du stehst diesem Antrag wieder neutral gegenüber.',
    'support_already'                    => 'Du unterstützt diesen Antrag bereits',
    'support_collection_hint'            => 'Dieser Antrag ist noch nicht eingereicht. Nötig sind <strong>mindestens %MIN% Unterstützer*innen (aktueller Stand: %CURR%)</strong>. Wenn du ihn unterstützen willst, kannst du das unten auf dieser Seite tun.',
    'support_collection_reached_hint'    => 'Dieser Antrag ist noch nicht eingereicht. <strong>Die Mindestzahl an Unterstützer*innen (%MIN%) wurde erreicht</strong>, nun muss nur noch die/der Antragsteller*in die Einreichung bestätigen. Eine Unterstützung des Antrags ist weiterhin möglich. ',
    'support_reached_email_subject'      => 'Dein Antrag: Unterstützer*innen-Anzahl erreicht',
    'support_reached_email_body'         => 'Hallo,<br><br>Gute Nachrichten! Dein Antrag "%TITLE%" hat die Mindestzahl an Unterstützer*innen erreicht.<br><br>Jetzt bist du noch einmal am Zug. Bitte reiche deinen Antrag nun offiziell bei der Antragskommission ein. Dies kannst du über Antragsgrün unter dem folgenden Link machen:<br><br><strong>%LINK%</strong><br><br>Der Antrag wird zeitnah nach einer formalen Prüfung im Antragsgrün veröffentlicht.<br><br>Viele Grüße,<br>  Das Antragsgrün-Team',
    'support_finish_btn'                 => 'Antrag offiziell einreichen',
    'support_finish_err'                 => 'Das ist derzeit (noch) nicht möglich',
    'support_finish_done'                => 'Der Antrag ist nun offiziell eingereicht',
    'prefix_new_code'                    => 'neu',
];

==> antragsgruen-3.7.1.tar.bz2: antragsgruen-3.7.1/messages/de/motion.php <==
<?php

return [
    'Start a Motion'                     => 'Antrag stellen',
    'Edit Motion'                        => 'Antrag bearbeiten',
    'Confirm Motion'                     => 'Antrag bestätigen',
    'confirm_bread'                      => 'Bestätigen',
    'create_prerequisites'               => 'Voraussetzungen für einen Antrag',
    'amendment_create'                   => 'Änderungsantrag stellen',
    'amendment_create_admin'             => 'nur Admins',
    'amendments_merge'                   => 'Änderungsanträge einpflegen',
    'amendments_merge_noamend'           => 'Änderungen einpflegen',
    'none_yet'                           => 'Es gibt noch keine Anträge',
    'motion_edit'                        => '%TYPE% bearbeiten',
    'motion_withdraw'                    => '%TYPE% zurückziehen',
    'motion_admin_edit'                  => 'Admin: bearbeiten',
    'back_start'                         => 'Zurück zur Übersicht',
    'pdf_version'                        => 'PDF-Version',
    'Type'                               => 'Typ',
    'Motion'                             => 'Antrag',
    'Initiator'                          => 'Antragsteller*in',
    'initiators_1'                       => 'Antragsteller*in',
    'initiators_x'                       => 'Antragsteller*innen',
    'initiators_head'                    => 'Antragsteller*innen',
    'Supporter'                          => 'Unterstützer*in',
    'supporters_heading'                 => 'Unterstützer*innen',
    'supporting_you'                     => 'Du!',
    'supporting_none'                    => 'keine',
    'supporting_logged_out_warning'      => 'Achtung: Du bist nicht eingeloggt. Unterstützungen, die ohne Login ausgesprochen werden, können nur für kurze Zeit zurückgenommen werden.',
    'supporting_no_orga_error'           => 'Achtung: dein Gremium konnte nicht ermittelt werden. Das ist zum Unterstützen aber notwendig. Bitte melde dich bei den Administrator*innen dieser Veranstaltung, um das Problem zu klären.',
    'likes_title'                        => 'Zustimmung',
    'like'                               => 'Zustimmung',
    'likes'                              => 'Zustimmung',
    'likes_you'                          => 'Du!',
    'dislike'                            => 'Ablehnung',
    'dislikes'                           => 'Ablehnung',
    'dislikes_you'                       => 'Du!',
    'like_withdraw'                      => 'Doch nicht',
    'submitted_create'                   => 'Antrag angelegt',
    'submitted_submit'                   => 'Antrag eingereicht',
    'submitted_publish'                  => 'Antrag veröffentlicht',
    'created_bread_create'               => 'Angelegt',
    'created_bread_submit'               => 'Eingereicht',
    'created_bread_publish'              => 'Veröffentlicht',
    'button_submit_create'               => 'Anlegen',
    'button_submit_submit'               => 'Einreichen',
    'button_submit_publish'              => 'Veröffentlichen',
    'button_correct'                     => 'Korrigieren',
    'Prefix'                             => 'Antragsnummer',
    'Title'                              => 'Titel',
    'replaces_motion'                    => 'Ersetzt',
    'consultation'                       => 'Veranstaltung',
    'comments'                           => 'Kommentare',
    'comment_screen_queue_1'             => '1 Kommentar wartet auf Freischaltung',
    'comment_screen_queue_x'             => '%NUM% Kommentare warten auf Freischaltung',
    'comment_login_hint'                 => 'Logge dich ein, um kommentieren zu können.',
    'status'                             => 'Status',
    'tag_none'                           => 'Keines',
    'as_pdf'                             => 'als PDF',
    'agenda_filter'                      => 'Tagesordnung',
    'agenda_item'                        => 'Tagesordnungspunkt',
    'resolution'                         => 'beschlossen',
    'resolution_on'                      => 'beschlossen am',
    'Resolution'                         => 'Beschlossen',
    'resoluted_on'                       => 'Entschieden am',
    'submitted_on'                       => 'Eingereicht',
    'created_on'                         => 'Angelegt',
    'tag_tags'                           => 'Themenbereich',
    'tag'                                => 'Themenbereich',
    'tags'                               => 'Themenbereiche',
    'tag_add'                            => 'Hinzufügen',
    'tag_select'                         => 'Thema aussuchen',
    'tag_new'                            => 'Neu',
    'tag_del'                            => 'del',
    'tags_head'                          => 'Themen',
    'merging_draft_th'                   => 'Überarbeitung',
    'merging_draft_td'                   => 'Der Antrag wird gerade überarbeitet.<br><a href="%URL%"><span class="glyphicon glyphicon-chevron-right"></span> Zwischenstand anzeigen</a>',
    'merging_draft_warning'              => 'Dies ist kein beschlossener Antrag, sondern ein Bearbeitungs-Zwischenstand!',
    'amends_none'                        => 'keine',
    'replaced_by_hint'                   => 'Achtung: dies ist eine alte Fassung; die aktuelle Fassung gibt es hier:',
    'confirmed_visible'                  => 'Du hast den Antrag veröffentlicht. Er ist jetzt sofort sichtbar.',
    'confirmed_screening'                => 'Du hast den Antrag eingereicht. ' .
        'Er wird nun auf formale Richtigkeit geprüft und dann freigeschaltet.',
    'confirmed_support_phase'            => 'Du hast den Antrag erfolgreich angelegt.<br>
Damit du den Antrag offiziell einreichen kannst, benötigt dieser mindestens %MIN% Unterstützer*innen.<br> 
<br>
Du kannst Interessierten folgenden Link schicken, damit sie deinen Antrag dort unterstützen können:',
    'confirmed_support_phase_ww'         => 'Über diesen Link kann dein Antrag gelesen und von Parteimitgliedern unterstützt werden, die damit mit Dir gemeinsam den Antrag stellen.<br> 
<br>
Bitte beachte, dass sich die Unterstützer*innen deines Antrags mit ihren Zugangsdaten für das Grüne Netz einloggen und darüber verifizieren müssen.',
    'copy_to_clipboard'                  => 'Adresse in die Zwischenablage kopieren',
    'copy_to_clipboard_done'             => 'Die Adresse wurde in die Zwischenablage kopiert.',
    'submitted_screening_email'          => "Hallo,\n\ndu hast soeben einen Antrag eingereicht.\n" .
        "Der Antrag wird nun auf formale Richtigkeit geprüft und dann freigeschaltet. " .
        "Du wirst dann gesondert darüber benachrichtigt.\n\n" .
        "Du kannst ihn hier einsehen: %LINK%\n\n" .
        "Mit freundlichen Grüßen,\n" .
        "  Das Antragsgrün-Team",
    'submitted_screening_email_subject'  => 'Antrag eingereicht',
    'submitted_supp_phase_email'         => "Hallo %NAME_GIVEN%\n\nDu hast den Antrag nun angelegt.\n" .
        "Um ihn offiziell einzureichen, benötigt er mindestens %MIN% Unterstützer*innen.\n\n" .
        "Du kannst Interessierten folgenden Link schicken, damit sie den Antrag dort unterstützen können:\n\n%LINK%\n",
    'submitted_supp_phase_email_subject' => 'Antrag erfolgreich angelegt',
    'submitted_adminnoti_title'          => 'Neuer Antrag',
    'submitted_adminnoti_body'           => "Es wurde ein neuer Antrag eingereicht.\nTitel: %TITLE%\nAntragsteller*in: %INITIATOR%\nLink: %LINK%",
    'screened_hint'                      => 'Geprüft',
    'supporting_permitted'               => 'Berechtigung',
    'download_pdf'                       => 'PDF-Version herunterladen',
    'motion_text'                        => 'Antragstext',
    'published_email_body'               => "Hallo,\n\ndein Antrag wurde soeben auf Antragsgrün veröffentlicht. " .
        "Du kannst ihn hier einsehen: %LINK%\n\n" .
        "Mit freundlichen Grüßen,\n" .
        "  Das Antragsgrün-Team",
    'published_email_title'              => 'Antrag veröffentlicht',
    'back_to_motion'                     => 'Zurück zum Antrag',
    'edit_done'                          => 'Antrag bearbeitet',
    'edit_done_msg'                      => 'Die Änderungen wurden übernommen.',
    'edit_bread'                         => 'Bearbeiten',
    'edit_mail_title'                    => 'Antrag überarbeitet',
    'edit_type'                          => '%TYPE% bearbeiten',
    'edit_mail_body'                     => 'Der Antrag "%TITLE%" wurde überarbeitet.' . "\n" . 'Link: %LINK%',
    'err_create_permission'              => 'Keine Berechtigung zum Anlegen von Anträgen.',
    'err_create'                         => 'Ein Fehler beim Anlegen ist aufgetreten',
    'err_edit_permission'                => 'Keine Berechtigung zum Bearbeiten dieses Antrags.',
    'err_withdraw_permission'            => 'Dieser Antrag kann nicht zurückgezogen werden.',
    'err_not_found'                      => 'Antrag nicht gefunden.',
    'err_not_visible_yet_title'          => 'Noch nicht sichtbar',
    'err_not_visible_yet'                => 'Dieser Antrag ist noch nicht sichtbar.',
    'err_draft_not_found'                => 'Es gibt keinen Bearbeitungs-Zwischenstand.',
    'withdraw_done'                      => 'Der Antrag wurde zurückgezogen.',
    'withdraw_bread'                     => 'Zurückziehen',
    'withdraw'                           => 'Zurückziehen',
    'withdraw_confirm'                   => 'Willst du diesen Antrag wirklich zurückziehen?',
    'withdraw_no'                        => 'Doch nicht',
    'withdraw_yes'                       => 'Zurückziehen',
    'withdrawn_adminnoti_title'          => 'Antrag zurückgezogen',
    'withdrawn_adminnoti_body'           => "Es wurde ein Antrag zurückgezogen.\nTitel: %TITLE%\nAntragsteller*in: %INITIATOR%\nLink: %LINK%",
    'max_len_hint'                       => 'Max. %LEN% Zeichen (Aktuell: %COUNT%)',
    'max_len_alert'                      => 'Der Text ist zu lang!',
    'create_explanation'                 => 'Wenn du einen <em>eigenständigen Antrag</em> stellen willst, bist du hier genau richtig.
        Wenn du einen <em>Änderungsantrag</em> stellen willst, öffne auf der <a href="%HOME%">Startseite</a>
        bitte zuerst den zu ändernden Antrag und wähle dann rechts oben "Änderungsantrag stellen".',
    'create_explanation_title'           => 'Antrag oder Änderungsantrag?',
    'support_collect_explanation_title'  => 'Einen Antrag gemeinschaftlich stellen',
    'support_collect_explanation'        => 'Ein Antrag, der nicht von Parteigremien gestellt wird, kann gemäß unserer Statuten auch gemeinschaftlich von %MIN+1% Mitgliedern gestellt werden. Um einen solchen Antrag zu stellen und offiziell bei der Antragskommission einzureichen, gehe bitte wie folgt vor:<br>
<ol>
<li><strong>Antrag anlegen:</strong> Bitte lege auf dieser Seite deinen Antrag an und hinterlege deine (Kontakt-)Daten. Kontrolliere auf der nächsten Seite, ob alles richtig ist, und bestätige, dass du den Antrag wie gezeigt anlegen möchtest.</li>
<li><strong>Unterstützung finden:</strong> Nach der Bestätigung erhältst du einen Link, den du Interessierten weiterleiten kannst. Über diesen Link kann dein Antrag gelesen und von Parteimitgliedern unterstützt werden, die damit mit Dir gemeinsam den Antrag stellen. Bitte beachte, dass sich auch die Unterstützer*innen deines Antrags mit ihren Zugangsdaten für das Grüne Netz einloggen und darüber verifizieren müssen.</li>
<li><strong>Antrag einreichen:</strong> Sobald sich die notwendigen %MIN% Unterstützer*innen gefunden haben, musst du den angelegten Antrag noch offiziell bei der Antragskommission einreichen. Dies veranlasst Du auch über Antragsgrün. Wir informieren dich selbstverständlich per E-Mail, sobald die notwendige Zahl der Unterstützer*innen erreicht ist.</li>
</ol>',
    'support_collect_status'             => 'Aktueller Stand',
    'support_collect_min'                => 'min.',
    'go_on'                              => 'Weiter',
    'like_done'                          => 'Du stimmst diesem Antrag nun zu.',
    'dislike_done'                       => 'Du lehnst diesen Antrag nun ab.',
    'support'                            => 'Unterstützen',
    'support_question'                   => 'Willst du den Antrag unterstützen?',
    'support_orga'                       => 'Organisation',
    'support_name'                       => 'Name',
    'support_done'                       => 'Du unterstützt diesen Antrag nun.',
    'neutral_done'                       => 'Du stehst diesem Antrag wieder neutral gegenüber.',
    'support_already'                    => 'Du unterstützt diesen Antrag bereits',
    'support_collection_hint'            => 'Dieser Antrag ist noch nicht eingereicht. Nötig sind <strong>mindestens %MIN% Unterstützer*innen (aktueller Stand: %CURR%)</strong>. Wenn du ihn unterstützen willst, kannst du das unten auf dieser Seite tun.',
    'support_collection_reached_hint'    => 'Dieser Antrag ist noch nicht eingereicht. <strong>Die Mindestzahl an Unterstützer*innen (%MIN%) wurde erreicht</strong>, nun muss nur noch die/der Antragsteller*in die Einreichung bestätigen. Eine Unterstützung des Antrags ist weiterhin möglich. ',
    'support_reached_email_subject'      => 'Dein Antrag: Unterstützer*innen-Anzahl erreicht',
    'support_reached_email_body'         => 'Hallo,<br><br>Gute Nachrichten! Dein Antrag "%TITLE%" hat die Mindestzahl an Unterstützer*innen erreicht.<br><br>Jetzt bist du noch einmal am Zug. Bitte reiche deinen Antrag nun offiziell bei der Antragskommission ein. Dies kannst du über Antragsgrün unter dem folgenden Link machen:<br><br><strong>%LINK%</strong><br><br>Der Antrag wird zeitnah nach einer formalen Prüfung im Antragsgrün veröffentlicht.<br><br>Viele Grüße,<br>  Das Antragsgrün-Team',
    'support_finish_btn'                 => 'Antrag offiziell einreichen',
    'support_finish_err'                 => 'Das ist derzeit (noch) nicht möglich',
    'support_finish_done'                => 'Der Antrag ist nun offiziell eingereicht',
    'prefix_new_code'                    => 'neu',
    'comment_for'                        => 'Kommentar zu',
];
